# pydtb


[![image](https://img.shields.io/pypi/v/pydtb.svg)](https://pypi.python.org/pypi/pydtb)
[![image](https://img.shields.io/conda/vn/conda-forge/pydtb.svg)](https://anaconda.org/conda-forge/pydtb)


**A python package for geological features interactive mapping.**


-   Free software: MIT license
-   Documentation: https://giswr.github.io/pydtb
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
